@@ -52,8 +52,10 @@
 #define STYLE_SECONDARY_CURSOR		"secondary-cursor"
 #define STYLE_CURRENT_LINE		"current-line"
 #define STYLE_LINE_NUMBERS		"line-numbers"
+#define STYLE_CURRENT_LINE_NUMBER	"current-line-number"
 #define STYLE_RIGHT_MARGIN		"right-margin"
 #define STYLE_DRAW_SPACES		"draw-spaces"
+#define STYLE_BACKGROUND_PATTERN	"background-pattern"
 
 #define STYLE_SCHEME_VERSION		"1.0"
 
@@ -368,32 +370,6 @@ gtk_source_style_scheme_get_filename (GtkSourceStyleScheme *scheme)
 	return scheme->priv->filename;
 }
 
-/**
- * _gtk_source_style_scheme_new:
- * @id: scheme id.
- * @name: scheme name.
- *
- * Returns: new empty #GtkSourceStyleScheme.
- *
- * Since: 2.0
- */
-GtkSourceStyleScheme *
-_gtk_source_style_scheme_new (const gchar *id,
-			      const gchar *name)
-{
-	GtkSourceStyleScheme *scheme;
-
-	g_return_val_if_fail (id != NULL, NULL);
-	g_return_val_if_fail (name != NULL, NULL);
-
-	scheme = g_object_new (GTK_SOURCE_TYPE_STYLE_SCHEME,
-			       "id", id,
-			       "name", name,
-			       NULL);
-
-	return scheme;
-}
-
 /*
  * get_color_by_name:
  * @scheme: a #GtkSourceStyleScheme.
@@ -634,6 +610,23 @@ _gtk_source_style_scheme_get_current_line_color (GtkSourceStyleScheme *scheme,
 	return get_color (style, FALSE, color);
 }
 
+/*
+ * Returns TRUE if the style for background-pattern-color is set in the scheme
+ */
+gboolean
+_gtk_source_style_scheme_get_background_pattern_color (GtkSourceStyleScheme *scheme,
+                                                       GdkRGBA              *color)
+{
+	GtkSourceStyle *style;
+
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme), FALSE);
+	g_return_val_if_fail (color != NULL, FALSE);
+
+	style = gtk_source_style_scheme_get_style (scheme, STYLE_BACKGROUND_PATTERN);
+
+	return get_color (style, FALSE, color);
+}
+
 static void
 update_cursor_colors (GtkWidget      *widget,
 		      GtkSourceStyle *style_primary,
@@ -839,6 +832,12 @@ generate_css_style (GtkSourceStyleScheme *scheme)
 		append_css_style (final_style, style, "GtkSourceView");
 	}
 
+	style = gtk_source_style_scheme_get_style (scheme, STYLE_CURRENT_LINE_NUMBER);
+	if (style != NULL)
+	{
+		append_css_style (final_style, style, ".current-line-number");
+	}
+
 	if (*final_style->str != '\0')
 	{
 		GError *error = NULL;
