@@ -2,7 +2,7 @@
  * test-search-context.c
  * This file is part of GtkSourceView
  *
- * Copyright (C) 2013 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2013, 2015 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -41,6 +41,35 @@ static void check_async_search_results (GtkSourceSearchContext *context,
 					gboolean                forward,
 					gboolean                start_check);
 
+/* If we are running from the source dir (e.g. during make check)
+ * we override the path to read from the data dir.
+ */
+static void
+init_style_scheme_manager (void)
+{
+	gchar *dir;
+
+	dir = g_build_filename (TOP_SRCDIR, "data", "styles", NULL);
+
+	if (g_file_test (dir, G_FILE_TEST_IS_DIR))
+	{
+		GtkSourceStyleSchemeManager *manager;
+		gchar **dirs;
+
+		manager = gtk_source_style_scheme_manager_get_default ();
+
+		dirs = g_new0 (gchar *, 2);
+		dirs[0] = dir;
+
+		gtk_source_style_scheme_manager_set_search_path (manager, dirs);
+		g_strfreev (dirs);
+	}
+	else
+	{
+		g_free (dir);
+	}
+}
+
 static void
 flush_queue (void)
 {
@@ -583,7 +612,6 @@ test_async_forward_search_normal (void)
 
 	gtk_text_buffer_set_text (text_buffer, "aaaa", -1);
 	gtk_source_search_settings_set_search_text (settings, "aa");
-	gtk_source_search_settings_set_wrap_around (settings, FALSE);
 
 	check_async_search_results (context, results, TRUE, TRUE);
 
@@ -705,7 +733,6 @@ test_async_backward_search_normal (void)
 
 	gtk_text_buffer_set_text (text_buffer, "aaaa", -1);
 	gtk_source_search_settings_set_search_text (settings, "aa");
-	gtk_source_search_settings_set_wrap_around (settings, FALSE);
 
 	check_async_search_results (context, results, FALSE, TRUE);
 
@@ -967,7 +994,10 @@ test_regex_at_word_boundaries (void)
 	GtkTextIter iter;
 	GtkTextIter match_start;
 	GtkTextIter match_end;
+	GtkTextIter start;
+	GtkTextIter end;
 	gint offset;
+	gchar *content;
 
 	gtk_text_buffer_set_text (text_buffer, "1234\n12345\n1234", -1);
 
@@ -992,6 +1022,38 @@ test_regex_at_word_boundaries (void)
 	offset = gtk_text_iter_get_offset (&match_end);
 	g_assert_cmpint (offset, ==, 15);
 
+	/* Test replace, see https://bugzilla.gnome.org/show_bug.cgi?id=740810 */
+
+	gtk_text_buffer_set_text (text_buffer, "&aa", -1);
+	gtk_source_search_settings_set_search_text (settings, "aa");
+	flush_queue ();
+
+	gtk_text_buffer_get_iter_at_offset (text_buffer, &match_start, 1);
+	gtk_text_buffer_get_end_iter (text_buffer, &match_end);
+	gtk_source_search_context_replace (context, &match_start, &match_end, "bb", -1, NULL);
+
+	gtk_text_buffer_get_start_iter (text_buffer, &start);
+	gtk_text_buffer_get_end_iter (text_buffer, &end);
+	content = gtk_text_iter_get_visible_text (&start, &end);
+	g_assert_cmpstr (content, ==, "&bb");
+	g_free (content);
+
+	/* Test replace multi-byte character */
+
+	gtk_text_buffer_set_text (text_buffer, "–aa", -1);
+	gtk_source_search_settings_set_search_text (settings, "aa");
+	flush_queue ();
+
+	gtk_text_buffer_get_iter_at_offset (text_buffer, &match_start, 1);
+	gtk_text_buffer_get_end_iter (text_buffer, &match_end);
+	gtk_source_search_context_replace (context, &match_start, &match_end, "bb", -1, NULL);
+
+	gtk_text_buffer_get_start_iter (text_buffer, &start);
+	gtk_text_buffer_get_end_iter (text_buffer, &end);
+	content = gtk_text_iter_get_visible_text (&start, &end);
+	g_assert_cmpstr (content, ==, "–bb");
+	g_free (content);
+
 	g_object_unref (source_buffer);
 	g_object_unref (settings);
 	g_object_unref (context);
@@ -1002,6 +1064,8 @@ main (int argc, char **argv)
 {
 	gtk_test_init (&argc, &argv);
 
+	init_style_scheme_manager ();
+
 	g_test_add_func ("/Search/occurrences-count/simple", test_occurrences_count_simple);
 	g_test_add_func ("/Search/occurrences-count/with-insert", test_occurrences_count_with_insert);
 	g_test_add_func ("/Search/occurrences-count/with-delete", test_occurrences_count_with_delete);
